Index: tools/testing/dart/dartino_test_suite.dart |
diff --git a/tools/testing/dart/fletch_test_suite.dart b/tools/testing/dart/dartino_test_suite.dart |
similarity index 89% |
rename from tools/testing/dart/fletch_test_suite.dart |
rename to tools/testing/dart/dartino_test_suite.dart |
index 33fc535dfb4e568515a13ddf950e59491a47cf22..86bbc1ceedae82df17a9c8c4ec0e8a5ce5681492 100644 |
--- a/tools/testing/dart/fletch_test_suite.dart |
+++ b/tools/testing/dart/dartino_test_suite.dart |
@@ -3,8 +3,8 @@ |
// BSD-style license that can be found in the LICENSE.md file. |
/// Test suite for running tests in a shared Dart VM. Take a look at |
-/// ../../../tests/fletch_tests/all_tests.dart for more information. |
-library test.fletch_test_suite; |
+/// ../../../tests/dartino_tests/all_tests.dart for more information. |
+library test.dartino_test_suite; |
import 'dart:io' as io; |
@@ -39,7 +39,7 @@ import 'status_file_parser.dart' show |
ReadTestExpectationsInto, |
TestExpectations; |
-import '../../../tests/fletch_tests/messages.dart' show |
+import '../../../tests/dartino_tests/messages.dart' show |
ErrorMessage, |
Info, |
ListTests, |
@@ -52,36 +52,36 @@ import '../../../tests/fletch_tests/messages.dart' show |
TimedOut, |
messageTransformer; |
-class FletchTestRuntimeConfiguration extends RuntimeConfiguration { |
+class DartinoTestRuntimeConfiguration extends RuntimeConfiguration { |
final String system; |
final String dartBinary; |
- FletchTestRuntimeConfiguration(Map configuration) |
+ DartinoTestRuntimeConfiguration(Map configuration) |
: system = configuration['system'], |
dartBinary = '${TestUtils.buildDir(configuration)}' |
'${io.Platform.pathSeparator}dart', |
super.subclass(); |
} |
-class FletchTestSuite extends TestSuite { |
+class DartinoTestSuite extends TestSuite { |
final String testSuiteDir; |
TestCompleter completer; |
- FletchTestSuite(Map configuration, this.testSuiteDir) |
- : super(configuration, "fletch_tests"); |
+ DartinoTestSuite(Map configuration, this.testSuiteDir) |
+ : super(configuration, "dartino_tests"); |
void forEachTest( |
void onTest(TestCase testCase), |
Map testCache, |
[void onDone()]) { |
this.doTest = onTest; |
- if (configuration['runtime'] != 'fletch_tests') { |
+ if (configuration['runtime'] != 'dartino_tests') { |
onDone(); |
return; |
} |
- FletchTestRuntimeConfiguration runtimeConfiguration = |
+ DartinoTestRuntimeConfiguration runtimeConfiguration = |
new RuntimeConfiguration(configuration); |
TestExpectations expectations = new TestExpectations(); |
@@ -111,7 +111,7 @@ class FletchTestSuite extends TestSuite { |
bool helperProgramExited = false; |
io.Process vmProcess; |
ReadTestExpectationsInto( |
- expectations, '$testSuiteDir/fletch_tests.status', |
+ expectations, '$testSuiteDir/dartino_tests.status', |
configuration).then((_) { |
return new io.File('$buildDir/gen/version.cc').readAsLines(); |
}).then((List<String> versionFileLines) { |
@@ -128,8 +128,8 @@ class FletchTestSuite extends TestSuite { |
}).then((io.ServerSocket server) { |
return io.Process.start( |
runtimeConfiguration.dartBinary, |
- ['-Dfletch-vm=$buildDir/fletch-vm', |
- '-Dfletch.version=$version', |
+ ['-Ddartino-vm=$buildDir/dartino-vm', |
+ '-Ddartino.version=$version', |
'-Ddart-sdk=third_party/dart/sdk/', |
'-Dtests-dir=tests/', |
'-Djava-home=$javaHome', |
@@ -142,8 +142,8 @@ class FletchTestSuite extends TestSuite { |
'-Dtest.dart.servicec-dir=tools/servicec/', |
'-c', |
'--packages=.packages', |
- '-Dtest.fletch_test_suite.port=${server.port}', |
- '$testSuiteDir/fletch_test_suite.dart']).then((io.Process process) { |
+ '-Dtest.dartino_test_suite.port=${server.port}', |
+ '$testSuiteDir/dartino_test_suite.dart']).then((io.Process process) { |
process.exitCode.then((_) { |
helperProgramExited = true; |
server.close(); |
@@ -169,8 +169,8 @@ class FletchTestSuite extends TestSuite { |
for (String name in testNames) { |
Set<Expectation> expectedOutcomes = expectations.expectations(name); |
TestCase testCase = new TestCase( |
- 'fletch_tests/$name', <Command>[], configuration, expectedOutcomes); |
- var command = new FletchTestCommand(name, completer); |
+ 'dartino_tests/$name', <Command>[], configuration, expectedOutcomes); |
+ var command = new DartinoTestCommand(name, completer); |
testCase.commands.add(command); |
if (!expectedOutcomes.contains(Expectation.SKIP)) { |
completer.expect(command); |
@@ -261,13 +261,13 @@ class FletchTestSuite extends TestSuite { |
final RegExp noLintFilter = |
new RegExp(r"[^\n]*\n[^\n]*\n[^\n]* // NO_LINT\n *\^+\n"); |
-class FletchTestOutputCommand implements CommandOutput { |
+class DartinoTestOutputCommand implements CommandOutput { |
final Command command; |
final Duration time; |
final Message message; |
final List<String> stdoutLines; |
- FletchTestOutputCommand( |
+ DartinoTestOutputCommand( |
this.command, |
this.message, |
this.time, |
@@ -340,29 +340,29 @@ class FletchTestOutputCommand implements CommandOutput { |
bool get compilationSkipped => false; |
} |
-class FletchTestCommand implements Command { |
+class DartinoTestCommand implements Command { |
final String _name; |
final TestCompleter _completer; |
- FletchTestCommand(this._name, this._completer); |
+ DartinoTestCommand(this._name, this._completer); |
- String get displayName => "fletch_test"; |
+ String get displayName => "dartino_test"; |
int get maxNumRetries => 0; |
- Future<FletchTestOutputCommand> run(int timeout) { |
+ Future<DartinoTestOutputCommand> run(int timeout) { |
Stopwatch sw = new Stopwatch()..start(); |
return _completer.run(this, timeout).then((NamedMessage message) { |
- FletchTestOutputCommand output = |
- new FletchTestOutputCommand( |
+ DartinoTestOutputCommand output = |
+ new DartinoTestOutputCommand( |
this, message, sw.elapsed, _completer.testOutput[message.name]); |
_completer.done(this); |
return output; |
}); |
} |
- String toString() => 'FletchTestCommand($_name)'; |
+ String toString() => 'DartinoTestCommand($_name)'; |
set displayName(_) => throw "not supported"; |
@@ -375,8 +375,8 @@ class FletchTestCommand implements Command { |
} |
class TestCompleter { |
- final Map<String, FletchTestCommand> expected = |
- new Map<String, FletchTestCommand>(); |
+ final Map<String, DartinoTestCommand> expected = |
+ new Map<String, DartinoTestCommand>(); |
final Map<String, Completer> completers = new Map<String, Completer>(); |
final Completer<List<String>> testNamesCompleter = |
new Completer<List<String>>(); |
@@ -439,18 +439,18 @@ class TestCompleter { |
return testNamesCompleter.future; |
} |
- void expect(FletchTestCommand command) { |
+ void expect(DartinoTestCommand command) { |
expected[command._name] = command; |
} |
- void done(FletchTestCommand command) { |
+ void done(DartinoTestCommand command) { |
expected.remove(command._name); |
if (expected.isEmpty) { |
allDone(); |
} |
} |
- Future run(FletchTestCommand command, int timeout) { |
+ Future run(DartinoTestCommand command, int timeout) { |
if (command._name == "self/testNeverCompletes") { |
// Ensure timeout test times out quickly. |
timeout = 1; |